# Autogenerated by Astropy-affiliated package astropy_helpers's setup.py on 2016-06-19 00:33:17.476484
from __future__ import unicode_literals
import datetime

version = "1.2"
githash = "3e044eb26395c8569e3e15bf821c6ae5eeea324a"


major = 1
minor = 2
bugfix = 0

release = True
timestamp = datetime.datetime(2016, 6, 19, 0, 33, 17, 476484)
debug = False

try:
    from ._compiler import compiler
except ImportError:
    compiler = "unknown"

try:
    from .cython_version import cython_version
except ImportError:
    cython_version = "unknown"
